import { utils, BytesLike, BaseContract, Signer, CallOverrides, BigNumber, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface MockInterface extends utils.Interface {
    contractName: string | "Mock";
    functions: {
        "erc1155()": FunctionFragment;
        "erc20()": FunctionFragment;
        "erc721()": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "erc1155", values?: undefined): string;
    encodeFunctionData(functionFragment: "erc20", values?: undefined): string;
    encodeFunctionData(functionFragment: "erc721", values?: undefined): string;
    decodeFunctionResult(functionFragment: "erc1155", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "erc20", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "erc721", data: BytesLike): Result;
    events: {};
}
interface Mock extends BaseContract {
    contractName: string | "Mock";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: MockInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        erc1155(overrides?: CallOverrides): Promise<[string]>;
        erc20(overrides?: CallOverrides): Promise<[string]>;
        erc721(overrides?: CallOverrides): Promise<[string]>;
    };
    erc1155(overrides?: CallOverrides): Promise<string>;
    erc20(overrides?: CallOverrides): Promise<string>;
    erc721(overrides?: CallOverrides): Promise<string>;
    callStatic: {
        erc1155(overrides?: CallOverrides): Promise<string>;
        erc20(overrides?: CallOverrides): Promise<string>;
        erc721(overrides?: CallOverrides): Promise<string>;
    };
    filters: {};
    estimateGas: {
        erc1155(overrides?: CallOverrides): Promise<BigNumber>;
        erc20(overrides?: CallOverrides): Promise<BigNumber>;
        erc721(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        erc1155(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        erc20(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        erc721(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}

export { Mock, MockInterface };
